@@ -3,6 +3,9 @@
 
 using namespace std;
 
+namespace Tauolapp
+{
+
 void TauolaEvent::undecayTaus(){
   
   std::vector<TauolaParticle*> particle_list;
@@ -19,16 +22,17 @@ void TauolaEvent::decayTaus(){
   particle_list = findStableParticles(Tauola::getDecayingParticle());
 
   while(particle_list.size()!=0){
-    //tau and its matching tau-like partner is removed from the list here:
+
+    // tau and its matching tau-like partner is removed from the list here:
     TauolaParticlePair t_pair(particle_list);
 
-    Plots::SANC(t_pair);
-
-    //    t_pair.print();
+    //t_pair.print();
     t_pair.decayTauPair();
     t_pair.checkMomentumConservation();
   }
-  eventEndgame();
-  return;
 
+  // Final event record modifications
+  eventEndgame();
 }
+
+} // namespace Tauolapp
